am 142f2d34: am f46cf902: am 3a7a4696: Merge "Replace "mips" with "mipmaps" since the MIPS gcc compiler defines mips to 1."

* commit '142f2d34bc8c1249c152934de18d11767d03fb68':
  Replace "mips" with "mipmaps" since the MIPS gcc compiler defines mips to 1.
diff --git a/cpp/Allocation.cpp b/cpp/Allocation.cpp
index c8e7182..00d207e 100644
--- a/cpp/Allocation.cpp
+++ b/cpp/Allocation.cpp
@@ -313,10 +313,10 @@
 
 
 sp<Allocation> Allocation::createTyped(sp<RS> rs, sp<const Type> type,
-                                    RsAllocationMipmapControl mips, uint32_t usage) {
+                                    RsAllocationMipmapControl mipmaps, uint32_t usage) {
     void *id = 0;
     if (rs->getError() == RS_SUCCESS) {
-        id = RS::dispatch->AllocationCreateTyped(rs->getContext(), type->getID(), mips, usage, 0);
+        id = RS::dispatch->AllocationCreateTyped(rs->getContext(), type->getID(), mipmaps, usage, 0);
     }
     if (id == 0) {
         rs->throwError(RS_ERROR_RUNTIME_ERROR, "Allocation creation failed");
@@ -326,11 +326,11 @@
 }
 
 sp<Allocation> Allocation::createTyped(sp<RS> rs, sp<const Type> type,
-                                    RsAllocationMipmapControl mips, uint32_t usage,
+                                    RsAllocationMipmapControl mipmaps, uint32_t usage,
                                     void *pointer) {
     void *id = 0;
     if (rs->getError() == RS_SUCCESS) {
-        id = RS::dispatch->AllocationCreateTyped(rs->getContext(), type->getID(), mips, usage,
+        id = RS::dispatch->AllocationCreateTyped(rs->getContext(), type->getID(), mipmaps, usage,
                                                  (uintptr_t)pointer);
     }
     if (id == 0) {
diff --git a/rs.spec b/rs.spec
index aab3d46..d765866 100644
--- a/rs.spec
+++ b/rs.spec
@@ -37,7 +37,7 @@
     param uint32_t dimX
     param uint32_t dimY
     param uint32_t dimZ
-    param bool mips
+    param bool mipmaps
     param bool faces
     param uint32_t yuv
     ret RsType
@@ -46,7 +46,7 @@
 AllocationCreateTyped {
     direct
     param RsType vtype
-    param RsAllocationMipmapControl mips
+    param RsAllocationMipmapControl mipmaps
     param uint32_t usages
     param uintptr_t ptr
     ret RsAllocation
@@ -55,7 +55,7 @@
 AllocationCreateFromBitmap {
     direct
     param RsType vtype
-    param RsAllocationMipmapControl mips
+    param RsAllocationMipmapControl mipmaps
     param const void *data
     param uint32_t usages
     ret RsAllocation
@@ -64,7 +64,7 @@
 AllocationCubeCreateFromBitmap {
     direct
     param RsType vtype
-    param RsAllocationMipmapControl mips
+    param RsAllocationMipmapControl mipmaps
     param const void *data
     param uint32_t usages
     ret RsAllocation
diff --git a/rsAllocation.cpp b/rsAllocation.cpp
index f6f4ac9..bb7fc17 100644
--- a/rsAllocation.cpp
+++ b/rsAllocation.cpp
@@ -592,9 +592,9 @@
 }
 
 RsAllocation rsi_AllocationCreateTyped(Context *rsc, RsType vtype,
-                                       RsAllocationMipmapControl mips,
+                                       RsAllocationMipmapControl mipmaps,
                                        uint32_t usages, uintptr_t ptr) {
-    Allocation * alloc = Allocation::createAllocation(rsc, static_cast<Type *>(vtype), usages, mips, (void*)ptr);
+    Allocation * alloc = Allocation::createAllocation(rsc, static_cast<Type *>(vtype), usages, mipmaps, (void*)ptr);
     if (!alloc) {
         return NULL;
     }
@@ -603,11 +603,11 @@
 }
 
 RsAllocation rsi_AllocationCreateFromBitmap(Context *rsc, RsType vtype,
-                                            RsAllocationMipmapControl mips,
+                                            RsAllocationMipmapControl mipmaps,
                                             const void *data, size_t sizeBytes, uint32_t usages) {
     Type *t = static_cast<Type *>(vtype);
 
-    RsAllocation vTexAlloc = rsi_AllocationCreateTyped(rsc, vtype, mips, usages, 0);
+    RsAllocation vTexAlloc = rsi_AllocationCreateTyped(rsc, vtype, mipmaps, usages, 0);
     Allocation *texAlloc = static_cast<Allocation *>(vTexAlloc);
     if (texAlloc == NULL) {
         ALOGE("Memory allocation failure");
@@ -616,7 +616,7 @@
 
     texAlloc->data(rsc, 0, 0, 0, RS_ALLOCATION_CUBEMAP_FACE_POSITIVE_X,
                    t->getDimX(), t->getDimY(), data, sizeBytes, 0);
-    if (mips == RS_ALLOCATION_MIPMAP_FULL) {
+    if (mipmaps == RS_ALLOCATION_MIPMAP_FULL) {
         rsc->mHal.funcs.allocation.generateMipmaps(rsc, texAlloc);
     }
 
@@ -625,14 +625,14 @@
 }
 
 RsAllocation rsi_AllocationCubeCreateFromBitmap(Context *rsc, RsType vtype,
-                                                RsAllocationMipmapControl mips,
+                                                RsAllocationMipmapControl mipmaps,
                                                 const void *data, size_t sizeBytes, uint32_t usages) {
     Type *t = static_cast<Type *>(vtype);
 
     // Cubemap allocation's faces should be Width by Width each.
     // Source data should have 6 * Width by Width pixels
     // Error checking is done in the java layer
-    RsAllocation vTexAlloc = rsi_AllocationCreateTyped(rsc, vtype, mips, usages, 0);
+    RsAllocation vTexAlloc = rsi_AllocationCreateTyped(rsc, vtype, mipmaps, usages, 0);
     Allocation *texAlloc = static_cast<Allocation *>(vTexAlloc);
     if (texAlloc == NULL) {
         ALOGE("Memory allocation failure");
@@ -654,7 +654,7 @@
         sourcePtr += copySize;
     }
 
-    if (mips == RS_ALLOCATION_MIPMAP_FULL) {
+    if (mipmaps == RS_ALLOCATION_MIPMAP_FULL) {
         rsc->mHal.funcs.allocation.generateMipmaps(rsc, texAlloc);
     }
 
diff --git a/rsType.cpp b/rsType.cpp
index 48a18cd..dba128d 100644
--- a/rsType.cpp
+++ b/rsType.cpp
@@ -295,10 +295,10 @@
 namespace renderscript {
 
 RsType rsi_TypeCreate(Context *rsc, RsElement _e, uint32_t dimX,
-                     uint32_t dimY, uint32_t dimZ, bool mips, bool faces, uint32_t yuv) {
+                     uint32_t dimY, uint32_t dimZ, bool mipmaps, bool faces, uint32_t yuv) {
     Element *e = static_cast<Element *>(_e);
 
-    return Type::getType(rsc, e, dimX, dimY, dimZ, mips, faces, yuv);
+    return Type::getType(rsc, e, dimX, dimY, dimZ, mipmaps, faces, yuv);
 }
 
 }
diff --git a/cpp/rsCppStructs.h b/cpp/rsCppStructs.h
index 0df201b..70931be 100644
--- a/cpp/rsCppStructs.h
+++ b/cpp/rsCppStructs.h
@@ -505,25 +505,25 @@
      * Creates an Allocation for use by scripts with a given Type.
      * @param[in] rs Context to which the Allocation will belong
      * @param[in] type Type of the Allocation
      * @param[in] mips desired mipmap behavior for the Allocation
      * @param[in] usage usage for the Allocation
      * @return new Allocation
      */
     static sp<Allocation> createTyped(sp<RS> rs, sp<const Type> type,
-                                   RsAllocationMipmapControl mips, uint32_t usage);
+                                   RsAllocationMipmapControl mipmaps, uint32_t usage);
 
     /**
      * Creates an Allocation for use by scripts with a given Type and a backing pointer. For use
      * with RS_ALLOCATION_USAGE_SHARED.
      * @param[in] rs Context to which the Allocation will belong
      * @param[in] type Type of the Allocation
      * @param[in] mips desired mipmap behavior for the Allocation
      * @param[in] usage usage for the Allocation
      * @param[in] pointer existing backing store to use for this Allocation if possible
      * @return new Allocation
      */
     static sp<Allocation> createTyped(sp<RS> rs, sp<const Type> type,
-                                   RsAllocationMipmapControl mips, uint32_t usage, void * pointer);
+                                   RsAllocationMipmapControl mipmaps, uint32_t usage, void * pointer);
 
     /**
      * Creates an Allocation for use by scripts with a given Type with no mipmaps.
@@ -505,25 +505,25 @@
      * @param[in] rs Context to which the Allocation will belong
      * @param[in] type Type of the Allocation
-     * @param[in] mips desired mipmap behavior for the Allocation
+     * @param[in] mipmaps desired mipmap behavior for the Allocation
      * @param[in] usage usage for the Allocation
      * @return new Allocation
@@ -505,25 +505,25 @@
      * @param[in] rs Context to which the Allocation will belong
      * @param[in] type Type of the Allocation
-     * @param[in] mips desired mipmap behavior for the Allocation
+     * @param[in] mipmaps desired mipmap behavior for the Allocation
      * @param[in] usage usage for the Allocation
      * @param[in] pointer existing backing store to use for this Allocation if possible